"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const colors_1 = __importDefault(require("colors"));
function percentageUptoPrecision(numerator, denominator, precision) {
    return Number(((numerator / denominator) * 100).toFixed(precision));
}
function percentagesUptoPrecision(numerators, denominator, precision) {
    return numerators.map((numerator) => percentageUptoPrecision(numerator, denominator, precision));
}
function generateAggregateMessage(dfaLabel, dfaDescription, finiteAutomatonTestInfo) {
    const { falsePositives, falseNegatives, truePositives, trueNegatives } = finiteAutomatonTestInfo;
    const totalCorrect = trueNegatives + truePositives;
    const totalIncorrect = falseNegatives + falsePositives;
    const totalStrings = totalCorrect + totalIncorrect;
    const correctPercentage = percentageUptoPrecision(totalCorrect, totalStrings, 5);
    const incorrectPercentage = (100 - correctPercentage).toFixed(5);
    const [falsePositivesPercentage, falseNegativesPercentage, truePositivesPercentage, trueNegativesPercentage,] = percentagesUptoPrecision([falsePositives, falseNegatives, truePositives, trueNegatives], totalStrings, 5);
    const descriptionStringWithColors = dfaDescription ? colors_1.default.bold(dfaDescription) + '\n' : '';
    const descriptionString = dfaDescription ? dfaDescription + '\n' : '';
    return {
        withColors: [
            colors_1.default.blue.bold(dfaLabel),
            descriptionStringWithColors + `Total: ` + colors_1.default.blue.bold(totalStrings.toString()) + '\n',
            `Incorrect: ` + colors_1.default.red.bold(totalIncorrect.toString()),
            `Incorrect(%): ` + colors_1.default.red.bold(incorrectPercentage.toString() + '%'),
            `False Positives: ` + colors_1.default.red.bold(falsePositives.toString()),
            `False Positives(%): ` + colors_1.default.red.bold(falsePositivesPercentage + '%'),
            `False Negatives: ` + colors_1.default.red.bold(falseNegatives.toString()),
            `False Negatives(%): ` + colors_1.default.red.bold(falseNegativesPercentage + '%') + '\n',
            `Correct: ` + colors_1.default.green.bold(totalCorrect.toString()),
            `Correct(%): ` + colors_1.default.green.bold(correctPercentage.toString() + '%'),
            `True Positives: ` + colors_1.default.green.bold(truePositives.toString()),
            `True Positives(%): ` + colors_1.default.green.bold(truePositivesPercentage + '%'),
            `True Negatives: ` + colors_1.default.green.bold(trueNegatives.toString()),
            `True Negatives(%): ` + colors_1.default.green.bold(trueNegativesPercentage + '%') + '\n',
        ].join('\n'),
        withoutColors: [
            dfaLabel,
            descriptionString + `Total: ` + totalStrings + '\n',
            `Incorrect: ` + totalIncorrect,
            `Incorrect(%): ` + incorrectPercentage.toString() + '%',
            `False Positives: ` + falsePositives.toString(),
            `False Positives(%): ` + falsePositivesPercentage + '%',
            `False Negatives: ` + falseNegatives.toString(),
            `False Negatives(%): ` + falseNegativesPercentage + '%' + '\n',
            `Correct: ` + totalCorrect,
            `Correct(%): ` + correctPercentage.toString() + '%',
            `True Positives: ` + truePositives.toString(),
            `True Positives(%): ` + truePositivesPercentage + '%',
            `True Negatives: ` + trueNegatives.toString(),
            `True Negatives(%): ` + trueNegativesPercentage + '%' + '\n',
        ].join('\n'),
    };
}
exports.default = generateAggregateMessage;
